@@ -45,7 +45,6 @@ KMime::Message::Ptr openPgpEncrypted(const QByteArray &content)
     contentType->setMimeType("multipart/encrypted");
     contentType->setBoundary(KMime::multiPartBoundary());
     contentType->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pgp-encrypted"));
-    contentType->setCategory(KMime::Headers::CCcontainer);
 
     auto cte = message->contentTransferEncoding();
     cte->setEncoding(KMime::Headers::CE7Bit);
@@ -105,7 +104,7 @@ QList<KMime::Message::Ptr> FileOpener::openFile(const QString &fileName)
 
     const auto content = file.readAll();
 
-    if (content.length() == 0) {
+    if (content.isEmpty()) {
         qCWarning(MIMETREEPARSER_CORE_LOG) << "File is empty";
         return {};
     }
